summaryrefslogtreecommitdiff
path: root/lib/rpmte.c
diff options
context:
space:
mode:
authorjbj <devnull@localhost>2004-04-01 12:56:54 +0000
committerjbj <devnull@localhost>2004-04-01 12:56:54 +0000
commit0d73d4699b47f839db61580687fc972f48dd42d6 (patch)
tree7d12f711857adbf2fff174ef48a8bdb96393751c /lib/rpmte.c
parent34daf7ced86d499d1b5fc08b0b0cc430fc8678e8 (diff)
downloadrpm-0d73d4699b47f839db61580687fc972f48dd42d6.tar.gz
rpm-0d73d4699b47f839db61580687fc972f48dd42d6.tar.bz2
rpm-0d73d4699b47f839db61580687fc972f48dd42d6.zip
revert buildtime tie breaking, not the right thing to do.
splint fiddles. CVS patchset: 7216 CVS date: 2004/04/01 12:56:54
Diffstat (limited to 'lib/rpmte.c')
-rw-r--r--lib/rpmte.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/lib/rpmte.c b/lib/rpmte.c
index b70de699d..6429379a7 100644
--- a/lib/rpmte.c
+++ b/lib/rpmte.c
@@ -85,8 +85,9 @@ static void delTE(rpmte p)
static void addTE(rpmts ts, rpmte p, Header h,
/*@dependent@*/ /*@null@*/ fnpyKey key,
/*@null@*/ rpmRelocation * relocs)
- /*@globals rpmGlobalMacroContext, h_errno, fileSystem @*/
- /*@modifies ts, p, h, rpmGlobalMacroContext, fileSystem @*/
+ /*@globals rpmGlobalMacroContext, h_errno, fileSystem, internalState @*/
+ /*@modifies ts, p, h,
+ rpmGlobalMacroContext, fileSystem, internalState @*/
{
int scareMem = 0;
HGE_t hge = (HGE_t)headerGetEntryMinMemory;